@@ -1,10 +1,6 @@
 import sympy as sy
 import IPython
 
-global DatosList,Orden
-DatosList = []
-Orden = 8
-
 def Inicializar():
   global DatosList,Orden
   DatosList = []
